@@ -2,7 +2,7 @@ package Pandoc::Filter;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use JSON;
 use Carp;
@@ -30,7 +30,7 @@ sub stringify {
 
 sub pandoc_filter(@) { ## no critic
     my $filter = Pandoc::Filter->new(@_);
-    my $ast = Pandoc::Elements::from_json(<STDIN>);
+    my $ast = Pandoc::Elements::pandoc_json(<STDIN>);
     $filter->apply($ast);
     my $json = JSON->new->utf8->allow_blessed->convert_blessed->encode($ast);
     #my $json = $ast->to_json; # TODO
@@ -53,7 +53,7 @@ sub apply {
     $meta ||= eval { $ast->[0]->{unMeta} } || { };
 
     foreach my $action (@$self) {
-        transform($ast, $action, $format || '', $meta);
+        Pandoc::Walker::transform($ast, $action, $format || '', $meta);
     }
     $ast;
 }
@@ -90,15 +90,18 @@ process a L<Pandoc|http://johnmacfarlane.net/pandoc/> abstract syntax tree
 (AST) serialized as JSON. See L<Pandoc::Elements> for documentation of AST
 elements.
 
-In most cases you better use the function interface in L<Pandoc::Walker> which
-this module is based on.
+This module is based on L<Pandoc::Walker> and its function C<transform>. Please
+consider using its function interface (C<transform>, C<query>, C<walk>) instead
+of this module.
 
 =head1 METHODS
 
 =head2 new( @action )
 
 Create a new filter with one or more action functions, given as code
-reference(s).
+reference(s). Each function is expected to return an element, an empty array
+reference, or C<undef> to modify, remove, or keep a traversed element in the
+AST.
 
 =head2 apply( $ast [, $format [ $metadata ] ] )
 
@@ -114,7 +117,7 @@ Document by default (if the AST is a Document root).
 Read a single line of JSON from STDIN, apply actions and print the resulting
 AST as single line of JSON. This function is roughly equivalent to
 
-    my $ast = Pandoc::Elements::from_json(<>);
+    my $ast = Pandoc::Elements::pandoc_json(<>);
     Pandoc::Filter->new(@action)->apply($ast);
     say $ast->to_json;
 
